@@ -20,7 +20,7 @@ except:
     url = 'https://github.com/sundarjhu/DAWGI_Lectures_2021/blob/main/Demo_DAWGI_HBM/Pleiades/'
     name = url + 'Pleiades_ruwe_cexcess_SelDist.txt'
     list_iso = url + 'List_Iso21_PARSEC_GaiaEDR3.txt'
-    it_title = url + 'Pleiades'
+    it_title = 'Pleiades'
 
 #print('file: ', name)
 
